@@ -18,7 +18,7 @@ __all__ = [
     "__version__",
 ]
 
-__author__ = "Julien Moura (Oslandia)"
+__author__ = "Julien Moura (Oslandia), Vincent Bré (Oslandia)"
 __copyright__ = "2021 - {0}, {1}".format(date.today().year, __author__)
 __email__ = "qgis@oslandia.com"
 __executable_name__ = "QGIS_DeploymentCLI.exe"
@@ -36,7 +36,7 @@ __uri_repository__ = "https://github.com/Guts/qgis-deployment-cli/"
 __uri_tracker__ = "https://github.com/Guts/qgis-deployment-cli/issues/"
 __uri__ = __uri_repository__
 
-__version__ = "0.12.0"
+__version__ = "0.13.0"
 __version_info__ = tuple(
     [
         int(num) if num.isdigit() else num
